@@ -7,7 +7,7 @@ use diagnostics;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw( auction );
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 #Variables global to the package	
 my $maximize_total_benefit;
@@ -43,7 +43,7 @@ sub auction { #							=> default values
 	$maximize_total_benefit = $args{maximize_total_benefit};
    
 	my $optimal_benefit = 0;
-	my %assignement_hash;  # assignement: a hash representing edges in the mapping, as in the Algorithm::Kuhn::Munkres.
+	my %assignment_hash;   # assignment: a hash representing edges in the mapping, as in the Algorithm::Kuhn::Munkres.
 	my @output_index;      # output_index: an array giving the number of the value assigned, as in the Algorithm::Munkres.
    
 	my @matrix;
@@ -53,7 +53,7 @@ sub auction { #							=> default values
 	}
 
 	if ( $max_size <= 1 ){ # matrix_input 1 x 1
-		$assignement_hash{0} = 0;
+		$assignment_hash{0} = 0;
 		$output_index[0] = 0;
 		$matrix_index[0] = 0;	
 		$optimal_benefit = $matrix_input[0]->[0];
@@ -147,7 +147,7 @@ sub auction { #							=> default values
 		#print " \$output_index[$index_i] = $index_j \n"; 	  
 	  
 		next unless ( defined $matrix_input[$index_i] and defined $matrix_input[$index_i]->[$index_j] );
-		$assignement_hash{ $index_i } = $index_j;	  
+		$assignment_hash{ $index_i } = $index_j;	  
 		$optimal_benefit += $matrix_input[$index_i]->[$index_j];
 	}
 
@@ -165,7 +165,7 @@ sub auction { #							=> default values
 	}   
 	print_screen_messages( \@matrix, \@matrix_index, \@matrix_input, \@output_index, $optimal_benefit, $args{verbose}, $epsilon ) ;
        
-	return ( $optimal_benefit, \%assignement_hash, \@output_index ) ;
+	return ( $optimal_benefit, \%assignment_hash, \@output_index ) ;
 }
 
 sub transpose {
@@ -439,7 +439,6 @@ sub auctionRound {
 			my ( $Opt01ObjForPersonI, $Opt02ObjForPersonI, $Opt03ObjForPersonI );
 			my ( $Opt01ValForPersonI, $Opt02ValForPersonI, $Opt03ValForPersonI ) = ( -10 * exp ($max_matrix_value), -10 * exp ($max_matrix_value), -10 * exp ($max_matrix_value) );
 			my ( $bid01ForPersonI, $bid02ForPersonI );
-			my %current_value;
             
 			# The working sets @objects_with_greater_benefits are updated dynamically by $objects_desired_by_this{$person} considering the price update of objects.
 			# For each person, the Current Value $curVal of the most desired objects contained in @objects_with_greater_benefits tend to converge to a specific value.
@@ -479,7 +478,7 @@ sub auctionRound {
 					$Opt03ValForPersonI = $curVal;
 					$Opt03ObjForPersonI = $object;
 				}
-
+				
 				if ( $verbose >= 8 ){
 					printf " personI = %3s ; objectJ = %3s ; Current Value %12.5f = \$matrix[%3s][%3s] %3.0f - \$price_object{%3s} %10.5f \n", $person, $object, $curVal, $person, $object, $matrix_value, $object, $price_object{$object};
 				}				
@@ -501,7 +500,7 @@ sub auctionRound {
 				
 					$objects_desired_by_this{$person}{$_} = $price_object{$_} for ( @objects_with_greater_benefits ); # update prices for all objects in the list
 					
-					delete $objects_desired_by_this{$person} if ( @objects_with_greater_benefits > 6 + $epsilon_scaling ) ; # delete old list
+					delete $objects_desired_by_this{$person} if ( $epsilon_scaling % 3 == 0 and @objects_with_greater_benefits > 3 * $epsilon_scaling ) ; # delete old list
 
 					$objects_desired_by_this{$person}{$Opt01ObjForPersonI} = $price_object{$Opt01ObjForPersonI}; # information about the most desired objects
 					$objects_desired_by_this{$person}{$Opt02ObjForPersonI} = $price_object{$Opt02ObjForPersonI} if (defined $Opt02ObjForPersonI);
@@ -514,8 +513,8 @@ sub auctionRound {
 				my @new_list = sort { $a <=> $b } keys %{$objects_desired_by_this{$person}};
 				my @best_3_objects = ( $Opt01ObjForPersonI, $Opt02ObjForPersonI, $Opt03ObjForPersonI );
 
-				printf "<> PersonI = %3s ; objects desired by this person (old list) = (@old_list) ; objects whose prices are still updated = (@updated_price) : %2s >= 1 ? \n", $person, scalar @updated_price;
-				printf "<> PersonI = %3s ; objects desired by this person (new list) = (@new_list) ; \@best_3_objects = (@best_3_objects) \n", $person if ( defined $Opt03ObjForPersonI );
+				printf "<> PersonI = %3s ; %3s objects desired by this person (old list) = (@old_list) ; objects whose prices are still updated = (@updated_price) : %2s >= 1 ? \n", $person, scalar @old_list, scalar @updated_price;
+				printf "<> PersonI = %3s ; %3s objects desired by this person (new list) = (@new_list) ; \@best_3_objects = (@best_3_objects) \n", $person, scalar @new_list if ( defined $Opt03ObjForPersonI );
 				printf "<> PersonI = %3s chose ObjectJ = %3s ; \$bid01ForPersonI %10.5f = \$Opt01ValForPersonI %.5f - \$Opt02ValForPersonI %.5f + \$epsilon %.5f \n", $person, $Opt01ObjForPersonI, $bid01ForPersonI, $Opt01ValForPersonI, $Opt02ValForPersonI, $epsilon;
 				printf "<> PersonI = %3s chose ObjectJ = %3s ; \$bid02ForPersonI %10.5f = \$Opt02ValForPersonI %.5f - \$Opt03ValForPersonI %.5f + \$epsilon %.5f \n", $person, $Opt02ObjForPersonI, $bid02ForPersonI, $Opt02ValForPersonI, $Opt03ValForPersonI, $epsilon if ( defined $bid02ForPersonI );
 			}
@@ -628,7 +627,7 @@ __END__
  98 [ 26  1 69 10 86 72 57 ]
   1 [ 71 98 28 87 11 25 40 ]
   
- my ( $optimal, $assignement_ref, $output_index_ref ) = auction( matrix_ref => \@input_matrix, maximize_total_benefit => 0, verbose => 5 );
+ my ( $optimal, $assignment_ref, $output_index_ref ) = auction( matrix_ref => \@input_matrix, maximize_total_benefit => 0, verbose => 5 );
   
  Objective: to Minimize the total benefit
  Number of left nodes: 4
@@ -695,7 +694,7 @@ __END__
  [  50,  80,  31,  90,  10,  83,  51,  55,  57,  40 ]
  );
 
- my ( $optimal, $assignement_ref, $output_index_ref ) = auction( matrix_ref => \@input_matrix, maximize_total_benefit => 1, verbose => 3 );
+ my ( $optimal, $assignment_ref, $output_index_ref ) = auction( matrix_ref => \@input_matrix, maximize_total_benefit => 1, verbose => 3 );
 
  Objective: to Maximize the total benefit
  Number of left nodes: 10
@@ -737,8 +736,8 @@ __END__
 
  Common use of the solution:
    
- foreach my $i ( sort { $a <=> $b } keys %{$assignement_ref} ){     
-   my $j = $assignement_ref->{$i};   
+ foreach my $i ( sort { $a <=> $b } keys %{$assignment_ref} ){     
+   my $j = $assignment_ref->{$i};   
    ...
  }
 
@@ -772,7 +771,7 @@ __END__
 =head1 OUTPUT
 
     The $output_index_ref is the reference to the output_index array.
-	The $assignement_ref  is the reference to the assignement hash.
+	The $assignment_ref  is the reference to the assignment hash.
 	The $optimal is the total benefit which can be a minimum or maximum value.
 	
 
@@ -797,7 +796,7 @@ __END__
 =head1 AUTHOR
 
     Claudio Fernandes de Souza Rodrigues
-	April 5, 2018
+	April 6, 2018
 	Sao Paulo, Brasil
 	claudiofsr@yahoo.com
 	
